@@ -657,21 +657,6 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
 
         self.assertEqual(mock_disk_2, physical_disk)
 
-    def test_get_dev_number_from_dev_name(self):
-        fake_physical_device_name = r'\\.\PhysicalDrive1'
-        expected_device_number = '1'
-
-        get_dev_number = self._vmutils.get_device_number_from_device_name
-        resulted_dev_number = get_dev_number(fake_physical_device_name)
-        self.assertEqual(expected_device_number, resulted_dev_number)
-
-    def test_get_device_number_from_invalid_device_name(self):
-        fake_physical_device_name = ''
-
-        self.assertRaises(exceptions.HyperVException,
-                          self._vmutils.get_device_number_from_device_name,
-                          fake_physical_device_name)
-
     def test_get_controller_volume_paths(self):
         self._prepare_mock_disk()
         mock_disks = {self._FAKE_RES_PATH: self._FAKE_HOST_RESOURCE}
@@ -752,13 +737,12 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
         self.assertEqual(mock_rasds, ret_val)
 
     def test_set_vm_serial_port_conn(self):
-        mock_vm = self._lookup_vm()
+        self._lookup_vm()
         mock_com_1 = mock.Mock()
         mock_com_2 = mock.Mock()
 
         self._vmutils._get_vm_serial_ports = mock.Mock(
             return_value=[mock_com_1, mock_com_2])
-        self._vmutils._modify_virt_resource = mock.Mock()
 
         self._vmutils.set_vm_serial_port_connection(
             mock.sentinel.vm_name,
@@ -766,8 +750,8 @@ class VMUtilsTestCase(test_base.OsWinBaseTestCase):
             pipe_path=mock.sentinel.pipe_path)
 
         self.assertEqual([mock.sentinel.pipe_path], mock_com_1.Connection)
-        self._vmutils._modify_virt_resource.assert_called_once_with(
-            mock_com_1, mock_vm.path_())
+        self._vmutils._jobutils.modify_virt_resource.assert_called_once_with(
+            mock_com_1)
 
     def test_get_serial_port_conns(self):
         self._lookup_vm()
