@@ -15,8 +15,8 @@
 import mock
 from oslotest import base
 
+from os_win import constants
 from os_win import exceptions
-from os_win.utils import constants
 from os_win.utils import hostutils
 
 
@@ -33,6 +33,9 @@ class FakeCPUSpec(object):
 class HostUtilsTestCase(base.BaseTestCase):
     """Unit tests for the Hyper-V hostutils class."""
 
+    _DEVICE_ID = "Microsoft:UUID\\0\\0"
+    _NODE_ID = "Microsoft:PhysicalNode\\0"
+
     _FAKE_MEMORY_TOTAL = 1024
     _FAKE_MEMORY_FREE = 512
     _FAKE_DISK_SIZE = 1024
@@ -175,3 +178,89 @@ class HostUtilsTestCase(base.BaseTestCase):
             mock_check_win.return_value = False
             result = self._hostutils.get_supported_vm_types()
             self.assertEqual([constants.IMAGE_PROP_VM_GEN_1], result)
+
+    def test_check_server_feature(self):
+        mock_sv_feature_cls = self._hostutils._conn_cimv2.Win32_ServerFeature
+        mock_sv_feature_cls.return_value = [mock.sentinel.sv_feature]
+
+        feature_enabled = self._hostutils.check_server_feature(
+            mock.sentinel.feature_id)
+        self.assertTrue(feature_enabled)
+
+        mock_sv_feature_cls.assert_called_once_with(
+            ID=mock.sentinel.feature_id)
+
+    def _check_get_numa_nodes_missing_info(self):
+        numa_node = mock.MagicMock()
+        self._hostutils._conn_virt.Msvm_NumaNode.return_value = [
+            numa_node, numa_node]
+
+        nodes_info = self._hostutils.get_numa_nodes()
+        self.assertEqual([], nodes_info)
+
+    @mock.patch.object(hostutils.HostUtils, '_get_numa_memory_info')
+    def test_get_numa_nodes_missing_memory_info(self, mock_get_memory_info):
+        mock_get_memory_info.return_value = None
+        self._check_get_numa_nodes_missing_info()
+
+    @mock.patch.object(hostutils.HostUtils, '_get_numa_cpu_info')
+    @mock.patch.object(hostutils.HostUtils, '_get_numa_memory_info')
+    def test_get_numa_nodes_missing_cpu_info(self, mock_get_memory_info,
+                                             mock_get_cpu_info):
+        mock_get_cpu_info.return_value = None
+        self._check_get_numa_nodes_missing_info()
+
+    @mock.patch.object(hostutils.HostUtils, '_get_numa_cpu_info')
+    @mock.patch.object(hostutils.HostUtils, '_get_numa_memory_info')
+    def test_get_numa_nodes(self, mock_get_memory_info, mock_get_cpu_info):
+        numa_memory = mock_get_memory_info.return_value
+        host_cpu = mock.MagicMock(DeviceID=self._DEVICE_ID)
+        mock_get_cpu_info.return_value = [host_cpu]
+        numa_node = mock.MagicMock(NodeID=self._NODE_ID)
+        numa_node.associators.return_value = [numa_memory, host_cpu]
+        self._hostutils._conn_virt.Msvm_NumaNode.return_value = [
+            numa_node, numa_node]
+
+        nodes_info = self._hostutils.get_numa_nodes()
+
+        expected_info = {
+            'id': self._DEVICE_ID.split('\\')[-1],
+            'memory': numa_memory.NumberOfBlocks,
+            'memory_usage': numa_node.CurrentlyConsumableMemoryBlocks,
+            'cpuset': set([self._DEVICE_ID.split('\\')[-1]]),
+            'cpu_usage': 0,
+        }
+
+        self.assertEqual([expected_info, expected_info], nodes_info)
+
+    def test_get_numa_memory_info(self):
+        numa_memory = mock.MagicMock()
+        numa_node = mock.MagicMock()
+        numa_node.associators.return_value = [numa_memory]
+        memory_info = self._hostutils._get_numa_memory_info(numa_node)
+
+        self.assertEqual(numa_memory, memory_info)
+
+    def test_get_numa_memory_info_not_found(self):
+        numa_node = mock.MagicMock()
+        numa_node.associators.return_value = []
+        memory_info = self._hostutils._get_numa_memory_info(numa_node)
+
+        self.assertIsNone(memory_info)
+
+    def test_get_numa_cpu_info(self):
+        host_cpu = mock.MagicMock()
+        host_cpu.path_.return_value = 'fake_wmi_obj_path'
+        vm_cpu = mock.MagicMock()
+        vm_cpu.path_return_value = 'fake_wmi_obj_path1'
+        numa_node_proc_path = ['fake_wmi_obj_path']
+        cpu_info = self._hostutils._get_numa_cpu_info(numa_node_proc_path,
+                                                      [host_cpu, vm_cpu])
+
+        self.assertEqual([host_cpu], cpu_info)
+
+    def test_get_numa_cpu_info_not_found(self):
+        other = mock.MagicMock()
+        cpu_info = self._hostutils._get_numa_cpu_info([], [other])
+
+        self.assertEqual([], cpu_info)
