@@ -20,7 +20,6 @@ Based on the "root/virtualization/v2" namespace available starting with
 Hyper-V Server / Windows Server 2012.
 """
 
-import re
 import sys
 import uuid
 
@@ -99,9 +98,6 @@ class VMUtils(object):
         if sys.platform == 'win32':
             self._init_hyperv_wmi_conn(host)
 
-        # Physical device names look like \\.\PHYSICALDRIVE1
-        self._phys_dev_name_regex = re.compile(r'\\\\.*\\[\w]*([\d])')
-
     def _init_hyperv_wmi_conn(self, host):
         self._conn = wmi.WMI(moniker='//%s/root/virtualization/v2' % host)
 
@@ -734,14 +730,6 @@ class VMUtils(object):
                 if disk_resource.HostResource[0].lower() == disk_path.lower():
                     return disk_resource
 
-    def get_device_number_from_device_name(self, device_name):
-        matches = self._phys_dev_name_regex.findall(device_name)
-        if matches:
-            return matches[0]
-        else:
-            err_msg = _("Could not find device number for device: %s")
-            raise exceptions.HyperVException(err_msg % device_name)
-
     def get_mounted_disk_by_drive_number(self, device_number):
         mounted_disks = self._conn.query("SELECT * FROM Msvm_DiskDrive "
                                          "WHERE DriveNumber=" +
@@ -812,7 +800,7 @@ class VMUtils(object):
         serial_port = self._get_vm_serial_ports(vm)[port_number - 1]
         serial_port.Connection = [pipe_path]
 
-        self._modify_virt_resource(serial_port, vm.path_())
+        self._jobutils.modify_virt_resource(serial_port)
 
     def get_vm_serial_port_connections(self, vm_name):
         vm = self._lookup_vm_check(vm_name)
